import 'package:dio/dio.dart';

import '../../../matule_query.dart';

class Client extends Repository {
  @override
  String get apiUrl => "https://api.matule.ru/api";

  AuthModel? _authModel;

  Options get options => Options(
    headers: {
      if (_authModel != null) "Authorization": "Bearer ${_authModel!.token}",
    },
  );

  @override
  Future<AuthModel> login(String identity, String password) async {
    Response response = await dio.post(
      "$apiUrl/collections/users/auth-with-password",
      data: {"identity": identity, "password": password},
    );
    _authModel = AuthModel.fromJSON(response.data);
    return _authModel!;
  }

  @override
  Future<MetadataModel> signup(
    String email,
    String password,
    String passwordConfirm,
  ) async {
    Response response = await dio.post(
      "$apiUrl/collections/users/records",
      data: {
        "email": email,
        "password": password,
        "passwordConfirm": passwordConfirm,
      },
    );
    return MetadataModel.fromJSON(response.data);
  }

  @override
  Future<MetadataModel> editProfile(
    String id,
    String? email,
    bool? emailVisibility,
    String? firstName,
    String? lastName,
    String? secondName,
    String? dateBirthday,
    String? gender,
  ) async {
    Response response = await dio.patch(
      "$apiUrl/collections/users/records/$id",
      options: options,
      data: FormData.fromMap({
        "email": email,
        "emailVisibility": emailVisibility,
        "firstname": firstName,
        "lastname": lastName,
        "secondname": secondName,
        "datebirthday": dateBirthday,
        "gender": gender,
      }),
    );
    return MetadataModel.fromJSON(response.data);
  }

  @override
  Future<List<ProductModel>> getProductList() async {
    Response response = await dio.get(
      "$apiUrl/collections/products/records",
      options: options,
    );
    return (response.data["items"] as List)
        .map((e) => ProductModel.fromJSON(e))
        .toList();
  }

  @override
  Future<List<ProductModel>> searchProductList(String search) async {
    Response response = await dio.get(
      "$apiUrl/collections/products/records",
      options: options,
      queryParameters: {"filter": "(title ?~ '$search')"},
    );
    return (response.data["items"] as List)
        .map((e) => ProductModel.fromJSON(e))
        .toList();
  }

  @override
  Future<ProductModel> getProduct(String id) async {
    Response response = await dio.get(
      "$apiUrl/collections/products/records/$id",
      options: options,
    );
    return ProductModel.fromJSON(response.data);
  }
}
