import 'dart:io';

import 'package:flutter_test/flutter_test.dart';
import "package:dio/dio.dart";
import 'package:matule_query/matule_query.dart';

String get testString => DateTime.now().millisecondsSinceEpoch.toString();

Options get options => Options(headers: {});

BaseUseCase useCase = BaseUseCase(startLoading: () {}, endLoading: () {});

onResponse(Object? obj) {
  stdout.writeln(obj.toString());
  assert(true);
}

onError(Exception e) {
  fail(e.toString());
}

final String _email = "example@test.russ";
final String _password = "stringss";
final String _productId = "45urlx4rj907rrk";

void main() {
  group("Query", () {
    test("Authorization", () async {
      await useCase.login(
        _email,
        _password,
        (obj) => onResponse(obj),
        (e) => onError(e),
      );
    });
    test("CreateUser", () async {
      late final AuthModel authModel;
      final String testEmail = "$testString@test.test";
      await useCase.signup(
        testEmail,
        _password,
        _password,
        (obj) => onResponse(obj),
        onError,
      );
      await useCase.login(testEmail, _password, (obj) {
        authModel = obj;
        onResponse(obj);
      }, onError);
      await useCase.editProfile(
        authModel.record.id,
        authModel.record.email,
        true,
        "firstName",
        "lastName",
        "secondName",
        "dateBirthday",
        "gender",
        onResponse,
        onError,
      );
    });
    test("ProductList", () async {
      await useCase.getProductList(onResponse, onError);
    });
    test("SearchProductList", () async {
      await useCase.searchProductList("Рубашка Среда", onResponse, onError);
    });
    test("GetProduct", () async {
      await useCase.getProduct(_productId, onResponse, onError);
    });
  });
}
